# -*- coding: utf-8 -*-
#
# ApplicationIntegrationServer - CSV Groups Example Plugin
#
# Copyright (c) 2014 - 2017 MailStore Software GmbH
#
# Permission is hereby granted, free of charge, to any person obtaining
# a copy of this software and associated documentation files (the
# "Software"), to deal in the Software without restriction, including
# without limitation the rights to use, copy, modify, merge, publish,
# distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so, subject to
# the following conditions:
#
# The above copyright notice and this permission notice shall be
# included in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
# LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
# OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
# WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

# https://docs.python.org/3/library/csv.html
import csv
import logging
import os.path


class Plugin:
    def __init__(self):
        self.logger = logging.getLogger("AppIntLogger")
        self.csv_file_name = "exCSVGroups.csv"
        self.csv_file_path = os.path.join(os.path.dirname(os.path.abspath(__file__)), self.csv_file_name)
        self.logger.info("CSV file loaded: {}".format(self.csv_file_path))
        self.fieldnames = ("userName", "fullName", "emailAddresses", "password", "group")
        self.http_user = "admin"
        self.http_pass = "password"

    def list_(self, data):
        groups = data["group"][0].split(",") if "group" in data and data["group"][0] else []
        self.logger.info("Requested Group(s): {}".format(", ".join(groups)))
        user_list = list()
        with open(self.csv_file_path, "r") as csv_file:
            userfile = csv.DictReader(csv_file, self.fieldnames, delimiter=";")
            for line in userfile:
                if groups and line["group"] not in groups:
                    self.logger.debug("Skipping user: {} ({})".format(line["userName"], line["group"]))
                    continue
                else:
                    self.logger.debug("Adding user: {} ({})".format(line["userName"], line["group"]))
                    user_list.append({"userName": line["userName"], "fullName": line["fullName"],
                                      "emailAddresses": line["emailAddresses"].split(",")})

        return user_list

    def auth(self, username, password):
        with open(self.csv_file_path, "r") as csv_file:
            userfile = csv.DictReader(csv_file, self.fieldnames, delimiter=";")
            for line in userfile:
                if username == line["userName"] and password == line["password"]:
                    self.logger.debug("Authentication success: {}".format(line["userName"]))
                    return {"succeeded": True}
        self.logger.debug("Authentication failed: {}".format(username))
        return {"succeeded": False}

    def http_authentication(self, username, password):
        success = (username == self.http_user and password == self.http_pass)
        self.logger.debug("HTTP Authentication success: {}".format(success))
        return success