# -*- coding: utf-8 -*-
#
# ApplicationIntegrationServer - SQLite Example Plugin
#
# Copyright (c) 2017 MailStore Software GmbH
#
# Permission is hereby granted, free of charge, to any person obtaining
# a copy of this software and associated documentation files (the
# "Software"), to deal in the Software without restriction, including
# without limitation the rights to use, copy, modify, merge, publish,
# distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so, subject to
# the following conditions:
#
# The above copyright notice and this permission notice shall be
# included in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
# LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
# OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
# WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

# https://docs.python.org/3/library/sqlite3.html
import sqlite3
import os


class Plugin:
    def __init__(self):
        self.sqlite_file_name = "exSQLite.db"
        self.sqlite_file_path = os.path.join(os.path.dirname(os.path.abspath(__file__)), self.sqlite_file_name)
        self.sqlite_table_name = "users"
        self.fieldnames_list = ["userName", "fullName", "emailAddresses"]
        self.fieldnames_auth = ["userName", "password"]

    def list_(self, _):
        connection = sqlite3.connect(self.sqlite_file_path)
        cursor = connection.cursor()
        cursor.execute('SELECT {} FROM {}'.format(",".join(self.fieldnames_list), self.sqlite_table_name))
        userlist = [{"userName": user[0],
                     "fullName": user[1],
                     "emailAddresses": user[2].split(",")} for user in cursor.fetchall()]
        connection.close()
        return userlist

    def auth(self, username, password):
        connection = sqlite3.connect(self.sqlite_file_path)
        cursor = connection.cursor()
        cursor.execute('SELECT {} FROM {} WHERE userName=? AND password=?'.format(",".join(self.fieldnames_auth),
                                                                                  self.sqlite_table_name),
                       (username, password))
        result = len(cursor.fetchall()) == 1
        connection.close()
        return {"succeeded": result}
